@@ -14,3 +14,6 @@ python manage.py createsuperuser \
     --noinput \
     --username freva-admin \
     --email $DJANGO_SUPERUSER_EMAIL || echo 0
+# python manage.py shell -c 'Site.objects.all().delete()'
+python manage.py shell -c \
+    'from django.contrib.sites.models import Site; Site.objects.create(id=1, domain="example.com", name="example.com").save()' || echo 0
